
# Mongolian p span


library(languageR)
library(lme4)
library(lattice)
library(MASS)
library(multcomp)
library(emmeans)
library(plyr) 
library(effects) 
library(dplyr) 

rm(list=ls())

datafile = read.csv(file.choose(), sep = ",", dec = ".")

colnames(datafile)



col.subject = 1      # specify which column your participant number is in
col.condition = 3     #specify which column contains your condition number
col.stim = 2       #specify which column your item number is in



# Work out which colums the fixed and random factors are in

datafile$pp = datafile[,col.subject]
datafile$condition = datafile[,col.condition]
datafile$stim = datafile[,col.stim]

#look at the structure of the datafile

str(datafile)

head(datafile)


#Are all variables the correct class? If not, change them...

datafile$RECORDING_SESSION_LABEL = as.factor(datafile$RECORDING_SESSION_LABEL)

datafile$AFD = as.integer(datafile$AFD)

# choose dependent variable
measure = "speed"

# add to dataframe
datafile$depvar = datafile[,measure



############

#make a matrix with the means per subject and per condition for the dependent variable
mean.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), mean, na.rm = T)
mean.matrix

#make a matrix with the standard deviations per subject and per condition for the dependent variable
sd.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), sd, na.rm = T)
sd.matrix

##############


#make a matrix with the means per subject and per condition for the dependent variable
mean.tt = tapply(datafile$depvar, list(datafile$pp, datafile$condition), mean, na.rm = T)
mean.tt

#make a matrix with the standard deviations per subject and per condition for the dependent variable (if you want more conditions, simply add the names)
sd.tt = tapply(datafile$depvar, list(datafile$pp, datafile$condition), sd, na.rm = T)
sd.tt

grand.mean=apply(mean.tt, 2, mean, na.rm = T)
grand.mean
grand.sd=apply(sd.tt,2,mean, na.rm = T)
grand.sd 
grand.se=grand.sd/sqrt(40)  ## this number is the total number of participants from your data, so it is changable.
grand.se
####################################################################################

levels(datafile$windowdescription)

# specify the contrasts

#Slding contrasts for orientation
contrasts(datafile$Orientation) <- contr.sdif(2)


# Contrast matrix for window
contrast.matrix <- matrix(c(   
  -1, +1, 0, 0, 0, 0,       # 0.5-0.5 vs 1.5-0.5
  0, -1, +1, 0, 0, 0,       # 1.5-0.5 vs 2.5-0.5
  0, 0, -1, +1, 0, 0,       # 2.5-0.5 vs 0.5-1.5
  0, 0, 0, -1, +1, 0,       # 0.5-1.5 vs 0.5-2.5
  0, 0, 0, 0, -1, +1), 6, 5,     #0.5-2.5 vs normal
  
  dimnames=list(c( "w1", "w2", "w3","w4", "w5", "w6"), 
                c( "w1.w2", "w2.w3","w3.w4", "w4.w5", "w5.w6")))


# inverse it before assigning to the contrasts
inv.contrast.matrix <- matrix(t(ginv(contrast.matrix)), 6, 5,
                              dimnames=list(c(  "w1", "w2", "w3","w4", "w5", "w6" ), 
                                            c("w1.w2", "w2.w3","w3.w4", "w4.w5", "w5.w6")))
(contrasts(datafile$window) <- fractions(inv.contrast.matrix))



# run the lmer model including an interaction
depvar.lmer3 = lmer(depvar ~ window*Orientation  + (1 + window + Orientation |Participant) + (1 + Orientation|sentence_number), datafile)


summary(depvar.lmer3, corr = FALSE)


# table of means for orientation x window
(table3 <- ddply(datafile,. (Orientation, window), summarise, M=mean(depvar, na.rm = TRUE), SD=sd(depvar, na.rm = TRUE), N=length(depvar[!is.na(depvar)]), SE=SD/sqrt(N) ))


isSingular (depvar.lmer2)

library(emmeans)
warnings()



emmeans(depvar.lmer2=3, "window * Orientation")
confint (depvar.lmer3)



# Log transform

# Do we need to log transform?
qqnorm(datafile$depvar)
qqnorm(log(datafile$depvar))


# If yes (repeat model)
datafile$depvar = log(datafile$depvar)

#subsets for model comparisons

q1<- subset(datafile, window== "w1" | window== "w2")
q1$window<- droplevels(q1$window)
q1$window<- factor(q1$window, levels=c("w1", "w2"))
contrasts(q1$window)

q2<- subset(datafile, window== "w2" | window== "w3")
q2$window<- droplevels(q2$window)
q2$window<- factor(q2$window, levels=c("w2", "w3"))
contrasts(q2$window)

q3<- subset(datafile, window== "w3" | window== "w4")
q3$window<- droplevels(q3$window)
q3$window<- factor(q3$window, levels=c("w3", "w4"))
contrasts(q3$window)

q4<- subset(datafile, window== "w4" | window== "w5")
q4$window<- droplevels(q4$window)
q4$window<- factor(q4$window, levels=c("w4", "w5"))
contrasts(q4$window)

q5<- subset(datafile, window== "w5" | window== "w6")
q5$window<- droplevels(q5$window)
q5$window<- factor(q5$window, levels=c("w5", "w6"))
contrasts(q5$window)



contrasts(q5$Orientation) <- contr.sdif(2)
contrasts(q5$window) <- contr.sdif(2)

#example subset


depvar.lmerq1 = lmer(speed ~ Orientation * window + (1  |Participant) + (1  |sentence_number), q5)

summary(depvar.lmerq1, corr = FALSE)

depvar.lmerq1a = lmer(speed ~ Orientation + window +(1  |Participant) + (1 |sentence_number), q5)

summary(depvar.lmerq1a, corr = FALSE)



anova (depvar.lmerq1, depvar.lmerq1a)











